# pysparklib

### A elaborate and developed PySpark libraries and resources


### Function list

- PMMLUtil


### Install
```bash
pip install pysparklib
```

---
&copy; 2019 Deyou Lee <deyoulee@126.com>